# project-config

[![PyPI][pypi-version-badge-link]][pypi-link]
[![Python versions][pv-image]][pypi-link]

[![License][license-image]][license-link]
[![Tests][tests-image]][tests-link]
[![Coverage][coverage-image]][coverage-link]

> Note for developers: This project is under heavy development.
> The testing and reporter APIs may change without warning before the
> first stable release (v1), but configuration, CLI and plugins are
> guaranteed to be backwards compatible, so you can safely write
> styles now.

## [Documentation](https://mondeja.github.io/project-config/latest/)

Lint the data files of your projects in a flexible way using JMESPaths.

[pypi-link]: https://pypi.org/project/project-config
[pypi-version-badge-link]: https://img.shields.io/pypi/v/project-config?logo=pypi&logoColor=white
[license-image]: https://img.shields.io/pypi/l/project-config?color=light-green&logo=freebsd&logoColor=white
[license-link]: https://github.com/mondeja/project-config/blob/master/LICENSE
[tests-image]: https://img.shields.io/github/actions/workflow/status/mondeja/project-config/ci.yml?logo=github&label=tests&branch=master
[tests-link]: https://github.com/mondeja/project-config/actions?query=workflow%3ACI
[coverage-image]: https://img.shields.io/codecov/c/github/mondeja/project-config?logo=codecov&logoColor=white
[coverage-link]: https://app.codecov.io/gh/mondeja/project-config
[pv-image]: https://img.shields.io/pypi/pyversions/project-config?logo=python&logoColor=white
